@@ -714,6 +714,7 @@ class Archipelagos:
                         features: List[str] = None,
                         max_size: int = -1,
                         ascending: bool = True,
+                        filters: Dict[str, str] = None,
                         returns: str = "pandas",
                         api_key: str = None) -> pd.DataFrame or np.ndarray or None:
         """
@@ -744,6 +745,9 @@ class Archipelagos:
         :param ascending: True if the data should be returned in ascending order, False otherwise.
         :type ascending: bool
 
+        :param filters: The filters that should be applied.
+        :type filters: Dict[str, str]
+
         :param returns: The object to be returned; "pandas" for a Pandas Data Frame or "numpy" for a Numpy array.
         :type returns: str
 
@@ -777,7 +781,7 @@ class Archipelagos:
 
                 # Send the time-series request to the platform
 
-                request = TimeSeriesRequest(source, category, label, start, end, features, max_size, ascending, api_key)
+                request = TimeSeriesRequest(source, category, label, start, end, features, max_size, ascending, filters, api_key)
                 response = Archipelagos.send(request)
 
                 # Inspect the result and return the appropriate type of object
@@ -799,6 +803,7 @@ class Archipelagos:
                        label: str,
                        features: List[str] = None,
                        max_size: int = -1,
+                       filters: Dict[str, str] = None,
                        returns: str = "pandas",
                        api_key: str = None) -> pd.DataFrame or np.ndarray or None:
         """
@@ -820,6 +825,9 @@ class Archipelagos:
         :param max_size: The (optional) maximum number of items that can be returned, or -1 if there should be no limit.
         :type max_size: int
 
+        :param filters: The filters that should be applied.
+        :type filters: Dict[str, str]
+
         :param returns: The object to be returned; "pandas" for a Pandas Data Frame or "numpy" for a Numpy array.
         :type returns: str
 
@@ -839,7 +847,7 @@ class Archipelagos:
             if return_pandas or return_numpy:
                 # Send the request to the platform
 
-                request = CollectionRequest(source, category, label, features, max_size, api_key)
+                request = CollectionRequest(source, category, label, features, max_size, filters, api_key)
                 response = Archipelagos.send(request)
 
                 # Inspect the result and return the appropriate type of object
